@@ -92,3 +92,30 @@ def getfinsnapnum(
                 if snapnum < minnum:
                     minnum=snapnum
         return minnum
+
+# Print iterations progress
+def printProgressBar (iteration, total, prefix = 'Progress:', suffix = 'complete', decimals = 1, length = 50, fill = '█', printEnd = "\r",force=False):
+    """
+    https://stackoverflow.com/questions/3173320/text-progress-bar-in-terminal-with-block-characters?noredirect=1&lq=1
+    Call in a loop to create terminal progress bar
+    @params:
+        iteration   - Required  : current iteration (Int)
+        total       - Required  : total iterations (Int)
+        prefix      - Optional  : prefix string (Str)
+        suffix      - Optional  : suffix string (Str)
+        decimals    - Optional  : positive number of decimals in percent complete (Int)
+        length      - Optional  : character length of bar (Int)
+        fill        - Optional  : bar fill character (Str)
+        printEnd    - Optional  : end character (e.g. "\r", "\r\n") (Str)
+    """
+    percent = ("{0:." + str(decimals) + "f}").format(100 * (iteration / float(total)))
+    filledLength = int(length * iteration // total)
+    bar = fill * filledLength + '-' * (length - filledLength)
+
+    n_iter_update = int(total//(100*10**(decimals))) ## update every 0.1% for decimals = 1
+
+    if force or n_iter_update <= 1 or not (iteration % n_iter_update): 
+        print(f'\r{prefix} |{bar}| {percent}% {suffix}', end = printEnd)
+    # Print New Line on Complete
+    if iteration == total: 
+        print()
